@@ -1,6 +1,16 @@
 #include <gtk/gtk.h>
 #include "cheese-flash.h"
 
+static gboolean
+delete_callback (GtkWidget *window,
+                 GdkEvent  *event,
+                 gpointer   data)
+{
+  gtk_widget_destroy (window);
+  gtk_main_quit ();
+  return FALSE;
+}
+
 static void
 button_clicked (GtkButton *button,
 		CheeseFlash *flash)
@@ -16,6 +26,8 @@ int main (int argc, char **argv)
 	gtk_init (&argc, &argv);
 
 	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+	g_signal_connect (G_OBJECT (window), "delete-event",
+			G_CALLBACK (delete_callback), NULL);
 	flash = cheese_flash_new (window);
 	button = gtk_button_new_with_label ("Fire flash");
 	g_signal_connect (G_OBJECT (button), "clicked",
